
/* ----------------------------------------------------------------------
                   SASEFRED Macro Library

        Name: fred_filegetxml.sas  
 Description: This macro uses the data step to read FRED data by
              referencing the previously established fileref
              (FILENAME trans URL) from already running the
              fred_filetransurl macro.
              The SASEFRED Interface Engine                   
       Title: Reading FRED Data in DATA STEP by URL Access.
     Product: SAS/ETS Software                                    
        Keys: FRED data extraction, XML FRED Data                             
       Procs: SASEFRED
       Notes: This is an uncompiled macro, used by SASEFRED to build     
              a FactSet Query for web access.
              30nov2012, saskff pulled for 13.1 copy at v940m1,
                         using s0923282.
            
              20Jul2015, saskff pulled to update 15.1 to https: instead of http:
                         using S1190360. Also added connect= option per Eric Thies suggestion.


     Support: saskff
  Parameters: fileref - filename handle (trans) for the URL transfer
              outXml  - no extension, filename for the XML
              dbug    - flag to get more debug info in the SAS log 
                        about the macro variables and their values. 
                        Uses PROC Printto to redirect the log    
                        information just like makefile.sas macro in
                        dvtest/testauto does.
             numIds   - integer, number that indicates the index of 
                        the time series that is passed to the macro. 
                        E.g., if idlist ='firstSeries, secondSeries', 
                        the numIds corresponding to firstSeries is 1, 
                        and thenumIds corresponding to secondSeries is 2.
--------------------------------------------------------------------------*/
%macro fred_filegetxml( outXml=,dbug=,numIds= );

    /*--- preset status to bad for early returns ---*/
    %let fred_macro_status=1;
    %let fred_xmlout_exist=1;

    %let debug=&dbug;

    %if %sysfunc(upcase(&debug))=ON %then %do;
       options mprint symbolgen;
    %end;
    %else %do;
       options nonotes;        /*  s1111072, unresolved macros...*/
                               /*  %filename(newlog,newlog,tmp); */
       filename newlog "newlog.tmp";
       proc printto log=newlog new;
       run;
       options notes;
    %end;

    options validvarname=any;

    /*--------------------------------------------------------*/
    /*--- Validation of parameters supplied to macro       ---*/
    /*--------------------------------------------------------*/
    %let nrbxout = %str(&outXml.&numIds);
    %let ext = %str(xml);

    %if %eval(%length(&nrbxout) ne 0) %then %do;
       %let glob = &nrbxout..&ext;
       filename outxml&numIds "&glob";

       data _NULL_;
       FILE outxml&numIds;
       INFILE trans&numIds; /*  must match fred_filetransurl's fileref */
       INPUT;
       PUT _infile_;
       RUN;

    %end;
    %else %do;
       filename outxml&numIds "xfredget.xml";

       data _NULL_;
       FILE outxml&numIds;
       INFILE trans&numIds; /*  must match fred_filetransurl's fileref */
       INPUT;
       PUT _infile_;
       RUN;
   
    %end;
  
    %let fred_outxml_exist = %sysfunc(FILEREF(outxml&numIds));
    %put NOTE: fred_outxml_exist flag is set to &fred_outxml_exist;

    %if %sysfunc(FILEREF(outxml&numIds)) ne 0 %then %do;
        %put %sysfunc(sysmsg());
        %goto bad_status; /* return bad status since no XML file for XMLV2 engine */
    %end;

    %let fred_macro_status=0;
   %bad_status:
   *-- unconditionally cut notes on --;
   options nonotes;
   
   %if %sysfunc(upcase(&debug))=OFF %then %do;
      proc printto log=log;
      run;

    /* -- s1111072, unresolved macros...*/
    /* -- %ridfile(newlog.tmp);         */

      %let rc = %sysfunc(fdelete(newlog));
   %end;
   

   options notes; options validvarname=any;

%mend fred_filegetxml;
